{% include rust2rpm_target ~ "-header.spec.inc" ignore missing %}
# Generated by rust2rpm {{ rust2rpm_version }}
%bcond_without check
{% if not (rpm_binary_package or rpm_cdylib_package) %}
%global debug_package %{nil}
{% endif %}

%global crate {{ crate_name }}
{% if crate_version != rpm_version %}
%global crate_version {{ crate_version }}
{% endif %}
{% if conf_supported_arches %}

# compile and run tests only on supported architectures
%global supported_arches {{ conf_supported_arches }}
{% endif %}

Name:           {{ rpm_name }}
Version:        {{ rpm_version }}
Release:        {{ rpm_release }}
{% if rpm_summary is none %}
Summary:        # FIXME
{% else %}
Summary:        {{ rpm_summary }}
{% endif %}
{% if rpm_group is defined %}
Group:          {{ rpm_group }}
{% endif %}

{% if crate_license != rpm_license %}
# Upstream license specification: {{ crate_license|default("(missing)") }}
{% endif %}
License:        {{ rpm_license|default("# FIXME") }}
{% if rpm_license_comments is not none %}
{{ rpm_license_comments }}
{% endif %}
URL:            https://crates.io/crates/{{ crate_name }}
{% if crate_version == rpm_version %}
Source:         %{crates_source}
{% else %}
Source:         %{crates_source %{crate} %{crate_version}}
{% endif %}
{% if rpm_patch_file_automatic is not none %}
# Automatically generated patch to strip foreign dependencies
Patch:          {{ rpm_patch_file_automatic }}
{% endif %}
{% if rpm_patch_file_manual is not none %}
{% if rust2rpm_target == "opensuse" %}
# PATCH-FIX-OPENSUSE {{ rpm_patch_file_manual }} — Manually created patch for downstream crate metadata changes
{% else %}
# Manually created patch for downstream crate metadata changes
{% endif %}
Patch:          {{ rpm_patch_file_manual }}
{% endif %}

{% if rust2rpm_target != "fedora" %}
ExclusiveArch:  %{rust_arches}

{% endif %}
BuildRequires:  {{ rust_packaging_dep }}
{% if include_build_requires %}
  {% for req in rpm_buildrequires %}
BuildRequires:  {{ req }}
  {% endfor %}
  {% if rpm_test_requires|length > 0 %}
%if %{with check}
    {% for req in rpm_test_requires %}
BuildRequires:  {{ req }}
    {% endfor %}
%endif
  {% endif %}
  {% for req in conf_buildrequires %}
BuildRequires:  {{ req }}
  {% endfor %}
  {% if conf_test_requires %}
%if %{with check}
  {% for req in conf_test_requires %}
BuildRequires:  {{ req }}
  {% endfor %}
%endif
  {% endif %}
{% endif %}

%global _description %{expand:
{% if rpm_description is none %}
%{summary}.
{%- else %}
{{ rpm_description }}
{%- endif %}
}

%description %{_description}

{% if rpm_binary_package or rpm_cdylib_package %}
%package     -n %{crate}
Summary:        %{summary}
  {% if rpm_group is defined %}
Group:          # FIXME
  {% endif %}
# FIXME: paste output of %%cargo_license_summary here
License:        # FIXME
# LICENSE.dependencies contains a full license breakdown
  {% for req in conf_bin_requires %}
Requires:       {{ req }}
  {% endfor %}

%description -n %{crate} %{_description}

%files       -n %{crate}
  {% if rpm_license_files|length > 0 %}
    {% for file in rpm_license_files %}
%license {{ file }}
    {% endfor %}
  {% else %}
# FIXME: no license files detected
  {% endif %}
%license LICENSE.dependencies
  {% for file in rpm_doc_files %}
%doc {{ file }}
  {% endfor %}
  {% for bin in rpm_binary_names %}
%{_bindir}/{{ bin }}
  {% endfor %}

{% endif -%}

{% if rpm_library_package %}
  {% for feature in crate_features %}
    {% if feature is none %}
      {% set pkg = "   devel" %}
      {% set conf_prefix = "lib" %}
    {% else %}
      {% set pkg = "-n %%{name}+%s-devel"|format(feature) %}
      {% set conf_prefix = "lib+%s"|format(feature) %}
    {% endif %}
%package     {{ pkg }}
Summary:        %{summary}
    {% if rpm_group is defined %}
Group:          {{ rpm_group }}
    {% endif %}
BuildArch:      noarch
    {% if include_provides %}
Provides:       {{ rpm_provides.get(feature) }}
    {% endif %}
    {% if include_requires %}
      {% for req in rpm_requires.get(feature) %}
Requires:       {{ req }}
      {% endfor %}
    {% endif %}
    {% for req in conf_lib_requires.get(conf_prefix) %}
Requires:       {{ req }}
    {% endfor %}

%description {{ pkg }} %{_description}

This package contains library source intended for building other packages which
use {% if feature is not none %}the "{{ feature }}" feature of {% endif %}the "%{crate}" crate.

%files       {{ pkg }}
    {% if feature is none %}
      {% if rpm_license_files|length > 0 %}
        {% for file in rpm_license_files %}
          {% if use_relative_license_paths %}
%license {{ file }}
          {% else %}
%license %{crate_instdir}/{{ file }}
          {% endif %}
        {% endfor %}
      {% else %}
# FIXME: no license files detected
      {% endif %}
      {% for file in rpm_doc_files %}
%doc %{crate_instdir}/{{ file }}
      {% endfor %}
%{crate_instdir}/
    {% else %}
%ghost %{crate_instdir}/Cargo.toml
    {% endif %}

  {% endfor %}
{% endif -%}

%prep
{% if crate_version == rpm_version %}
%autosetup -n %{crate}-%{version_no_tilde} -p1
{% else %}
%autosetup -n %{crate}-%{crate_version} -p1
{% endif %}
%cargo_prep

{% if not include_build_requires %}
%generate_buildrequires
%cargo_generate_buildrequires{{ cargo_args }}
  {% for req in conf_buildrequires %}
echo {{ "%r" | format(req) }}
  {% endfor %}
  {% if conf_test_requires %}
%if %{with check}
  {% for req in conf_test_requires %}
echo {{ "%r" | format(req) }}
  {% endfor %}
%endif
  {% endif %}

{% endif -%}

%build
{% if conf_supported_arches %}
%ifarch %{supported_arches}
{% endif %}
%cargo_build{{ cargo_args }}
{% if conf_supported_arches %}
%endif
{% endif %}
{% if rpm_binary_package or rpm_cdylib_package %}
%{cargo_license_summary{{ cargo_args }}}
%{cargo_license{{ cargo_args }}} > LICENSE.dependencies
{% endif %}

%install
{% if rpm_cdylib_package and (rpm_library_package or rpm_binary_package) %}
%cargo_install{{ cargo_args }}
# FIXME: install shared library
{% elif rpm_cdylib_package %}
# FIXME: install shared library
{% else %}
%cargo_install{{ cargo_args }}
{% endif %}

%if %{with check}
{% if conf_supported_arches %}
%ifarch %{supported_arches}
{% endif %}
%check
%cargo_test{{ cargo_args }}
{% if conf_supported_arches %}
%endif
{% endif %}
%endif

%changelog
{% if use_rpmautospec %}
%autochangelog
{%- else %}
{%- if make_changelog_entry -%}

  {% include rust2rpm_target ~ "-changelog.spec.inc" %}
{% endif %}
{% endif %}
